@@ -37,10 +37,9 @@ def write_text(filename, content):
 def run_cmd(cmd):
     try:
         # ignore stdout and stderr
-        # FIXME: redirect output to /dev/null
         proc = subprocess.Popen(cmd,
-                                stdout=subprocess.PIPE,
-                                stderr=subprocess.PIPE)
+                                stdout=subprocess.DEVNULL,
+                                stderr=subprocess.DEVNULL)
     except OSError as exc:
         if exc.errno == errno.ENOENT:
             return 127
@@ -214,7 +213,7 @@ class TurboBoostMSR(Operation):
             fd = os.open(path, os.O_WRONLY)
             try:
                 if hasattr(os, 'pwrite'):
-                    data = os.pwrite(fd, data, reg_num)
+                    os.pwrite(fd, data, reg_num)
                 else:
                     os.lseek(fd, reg_num, os.SEEK_SET)
                     os.write(fd, data)
@@ -866,6 +865,12 @@ class PowerSupply(Operation):
     def read_power_supply(self):
         # Python implementation of the on_ac_power shell script
         for name in os.listdir(self.path):
+            # Ignore "USB" and "Battery" types
+            filename = os.path.join(self.path, name, 'type')
+            sys_type = self.read_first_line(filename)
+            if sys_type.strip() != "Mains":
+                continue
+
             filename = os.path.join(self.path, name, 'online')
             if not os.path.exists(filename):
                 continue
