@@ -1,34 +1,22 @@
 import contextlib
-import datetime
 import math
 import os
 import statistics
 import sys
+import sysconfig
 from shlex import quote as shell_quote   # noqa
 from shutil import which
 
-
+# Currently there is a packaging issue for PEP-703,
+# Until then psutil is disabled as a workaround.
+# See: https://github.com/python/cpython/issues/116024
+USE_PSUTIL = not bool(sysconfig.get_config_var('Py_GIL_DISABLED'))
 MS_WINDOWS = (sys.platform == 'win32')
 MAC_OS = (sys.platform == 'darwin')
 
 if MS_WINDOWS:
     import msvcrt
 
-
-def parse_iso8601(date):
-    if '.' in date:
-        date, floatpart = date.split('.', 1)
-        floatpart = float('.' + floatpart)
-    else:
-        floatpart = 0
-    try:
-        dt = datetime.datetime.strptime(date, '%Y-%m-%d %H:%M:%S')
-    except ValueError:
-        dt = datetime.datetime.strptime(date, '%Y-%m-%dT%H:%M:%S')
-    dt += datetime.timedelta(seconds=floatpart)
-    return dt
-
-
 # A table of 95% confidence intervals for a two-tailed t distribution, as a
 # function of the degrees of freedom. For larger degrees of freedom, we
 # approximate. While this may look less elegant than simply calculating the
@@ -205,7 +193,9 @@ def python_has_jit():
     implementation_name = python_implementation()
     if implementation_name == 'pypy':
         return sys.pypy_translation_info["translation.jit"]
-    elif implementation_name == 'graalpython':
+    elif implementation_name in ['graalpython', 'graalpy']:
+        return True
+    elif hasattr(sys, "pyston_version_info") or "pyston_lite" in sys.modules:
         return True
     return False
 
@@ -277,7 +267,7 @@ def create_environ(inherit_environ, locale, copy_all):
         return os.environ
     env = {}
 
-    copy_env = ["PATH", "HOME", "TEMP", "COMSPEC", "SystemRoot", "SystemDrive"]
+    copy_env = ["PATH", "PYTHONPATH", "HOME", "TEMP", "COMSPEC", "SystemRoot", "SystemDrive"]
     if locale:
         copy_env.extend(('LANG', 'LC_ADDRESS', 'LC_ALL', 'LC_COLLATE',
                          'LC_CTYPE', 'LC_IDENTIFICATION', 'LC_MEASUREMENT',
@@ -369,7 +359,7 @@ def median_abs_dev(values):
 
 
 def percentile(values, p):
-    if not isinstance(p, float) or not(0.0 <= p <= 1.0):
+    if not isinstance(p, float) or not (0.0 <= p <= 1.0):
         raise ValueError("p must be a float in the range [0.0; 1.0]")
 
     values = sorted(values)
@@ -405,3 +395,23 @@ def geometric_mean(data):
     if not data:
         raise ValueError("empty data")
     return _geometric_mean(data)
+
+
+def merge_profile_stats(profiler, dst):
+    """
+    Save pstats by merging into an existing file.
+    """
+    import pstats
+    if os.path.isfile(dst):
+        try:
+            src_stats = pstats.Stats(profiler)
+        except TypeError:
+            # If no actual stats were collected, a TypeError is raised
+            # and we don't need to merge anything into the output.
+            return
+
+        dst_stats = pstats.Stats(dst)
+        dst_stats.add(src_stats)
+        dst_stats.dump_stats(dst)
+    else:
+        profiler.dump_stats(dst)
